@@ -1,18 +1,16 @@
 package Reddit::Client;
 
-our $VERSION = '0.9_1';
+our $VERSION = '0.05';
 $VERSION = eval $VERSION;
 
-use strict;
-use warnings;
 use Carp;
-
 use Data::Dumper   qw/Dumper/;
 use JSON           qw//;
+use LWP::UserAgent qw//;
+use HTTP::Request  qw//;
 use File::Spec     qw//;
 use Digest::MD5    qw/md5_hex/;
 use POSIX          qw/strftime/;
-use File::Path::Expand qw//;
 
 require Reddit::Client::Account;
 require Reddit::Client::Comment;
@@ -93,11 +91,11 @@ $API[API_DEL        ] = ['POST', '/api/del'       ];
 
 sub DEBUG {
     if ($DEBUG) {
-        my ($format, @args) = @_;
-        my $ts  = strftime "%Y-%m-%d %H:%M:%S", localtime;
-        my $msg = sprintf $format, @args;
-        chomp $msg;
-        printf STDERR "[%s] [ %s ]\n", $ts, $msg;
+	    my ($format, @args) = @_;
+	    my $ts  = strftime "%a %b %e %H:%M:%S %Y", localtime;
+	    my $msg = sprintf $format, @args;
+	    chomp $msg;
+	    printf STDERR "[%s] [ %s ]\n", $ts, $msg;
     }
 }
 
@@ -111,7 +109,7 @@ sub subreddit {
         if ($subject eq '') { # front page
             return '';
         } else {              # subreddit
-            return $subject;
+	        return $subject;
         }
     } else { # fail
         return;
@@ -126,19 +124,12 @@ use fields (
     'modhash',      # store session modhash
     'cookie',       # store user cookie
     'session_file', # path to session file
-    'user_agent',   # user agent string
 );
 
 sub new {
     my ($class, %param) = @_;
     my $self = fields::new($class);
 
-    if (not exists $param{user_agent}) {
-        carp "Reddit::Client->new: user_agent required in future version.";
-        $param{user_agent} = $UA;
-    }
-    $self->{user_agent} = $param{user_agent};
-
     if ($param{session_file}) {
         $self->{session_file} = $param{session_file};
         $self->load_session;
@@ -157,7 +148,7 @@ sub request {
     $path =~ s/^\/+//;
 
     my $request = Reddit::Client::Request->new(
-        user_agent => $self->{user_agent},
+        user_agent => $UA,
         url        => sprintf('%s/%s', $BASE_URL, $path),
         method     => $method,
         query      => $query,
@@ -175,9 +166,9 @@ sub json_request {
 
     if ($method eq 'POST') {
         $post_data ||= {};
-        $post_data->{api_type} = 'json';
+	    $post_data->{api_type} = 'json';
     } else {
-        $path .= '.json';
+	    $path .= '.json';
     }
 
     my $response = $self->request($method, $path, $query, $post_data);
@@ -257,9 +248,7 @@ sub save_session {
 
     # Prepare session and file path
     my $session   = { modhash => $self->{modhash}, cookie => $self->{cookie} };
-    my $file_path = File::Path::Expand::expand_filename(
-        defined $file ? $file : $self->{session_file}
-    );
+    my $file_path = defined $file ? $file : $self->{session_file};
 
     DEBUG('Save session to %s', $file_path);
 
@@ -277,9 +266,7 @@ sub save_session {
 sub load_session {
     my ($self, $file) = @_;
     $self->{session_file} || $file || croak 'Expected $file';
-    my $file_path = File::Path::Expand::expand_filename(
-        defined $file ? $file : $self->{session_file}
-    );
+    my $file_path = defined $file ? $file : $self->{session_file};
 
     DEBUG('Load session from %s', $file_path);
 
@@ -342,9 +329,9 @@ sub list_subreddits {
     defined $type || croak 'Expected $type"';
 
     $self->require_login
-        if $type eq SUBREDDITS_MOD
-        || $type eq SUBREDDITS_MINE
-        || $type eq SUBREDDITS_CONTRIB;
+	    if $type eq SUBREDDITS_MOD
+	    || $type eq SUBREDDITS_MINE
+	    || $type eq SUBREDDITS_CONTRIB;
 
     my $result = $self->api_json_request(api => API_SUBREDDITS, args => [$type]);
     return {
@@ -395,16 +382,15 @@ sub fetch_links {
 
     my $query  = {};
     if ($before || $after || $limit) {
-        $query->{limit}  = $limit  if defined $limit;
-        $query->{before} = $before if defined $before;
-        $query->{after}  = $after  if defined $after;
+	    $query->{limit}  = $limit  if defined $limit;
+	    $query->{before} = $before if defined $before;
+	    $query->{after}  = $after  if defined $after;
     }
 
     $subreddit = subreddit($subreddit);
-
-    my $args = [$view];
-    unshift @$args, $subreddit if $subreddit;
-
+    $args = [$view];
+    push @$args, $subreddit if $subreddit;
+    
     my $result = $self->api_json_request(
         api      => ($subreddit ? API_LINKS_FRONT : API_LINKS_OTHER),
         args     => $args,
@@ -427,9 +413,9 @@ sub delete_item {
     my ($self, %param) = @_;
     my $name = $param{name} || croak 'Expected "name"';
     $self->require_login;
-
+    
     DEBUG('Delete post/comment %s', $name);
-
+    
     my $result = $self->api_json_request(api => API_DEL, data => { id => $name });
     return 1;
 }
@@ -571,15 +557,16 @@ __END__
 
 Reddit::Client - A perl wrapper for Reddit
 
+=head1 VERSION
+
+Version 0.01
+
 =head1 SYNOPSIS
 
     use Reddit::Client;
 
     my $session_file = '~/.reddit';
-    my $reddit       = Reddit::Client->new(
-        session_file => $session_file,
-        user_agent   => 'MyApp/1.0',
-    );
+    my $reddit       = Reddit::Client->new(session_file => $session_file);
 
     unless ($reddit->is_logged_in) {
         $reddit->login('someone', 'secret');
@@ -608,26 +595,24 @@ For more information about the Reddit API, see L<https://github.com/reddit/reddi
 
 =head1 CONSTANTS
 
-Note that none of these constants are exported by C<Reddit::Client>.
+	VIEW_HOT            "Hot" links feed
+	VIEW_NEW            "New" links feed
+	VIEW_CONTROVERSIAL  "Controversial" links feed
+	VIEW_TOP            "Top" links feed
+	
+	VIEW_DEFAULT        Default feed if not specified (VIEW_HOT)
+	DEFAULT_LIMIT       The default number of links to be retried (25)
+	
+	VOTE_UP             Up vote
+	VOTE_DOWN           Down vote
+	VOTE_NONE           "Un" vote
 
-    VIEW_HOT            "Hot" links feed
-    VIEW_NEW            "New" links feed
-    VIEW_CONTROVERSIAL  "Controversial" links feed
-    VIEW_TOP            "Top" links feed
-
-    VIEW_DEFAULT        Default feed if not specified (VIEW_HOT)
-    DEFAULT_LIMIT       The default number of links to be retried (25)
-
-    VOTE_UP             Up vote
-    VOTE_DOWN           Down vote
-    VOTE_NONE           "Un" vote
-
-    SUBREDDITS_HOME     List reddits on the homepage
-    SUBREDDITS_POPULAR  List popular reddits
-    SUBREDDITS_NEW      List new reddits
-    SUBREDDITS_MINE     List reddits for which the logged in user is subscribed
-    SUBREDDITS_CONTRIB  List reddits for which the logged in user is a contributor
-    SUBREDDITS_MOD      List reddits for which the logged in user is a moderator
+	SUBREDDITS_HOME     List reddits on the homepage
+	SUBREDDITS_POPULAR  List popular reddits
+	SUBREDDITS_NEW      List new reddits
+	SUBREDDITS_MINE     List reddits for which the logged in user is subscribed
+	SUBREDDITS_CONTRIB  List reddits for which the logged in user is a contributor
+	SUBREDDITS_MOD      List reddits for which the logged in user is a moderator
 
 =head1 GLOBALS
 
@@ -636,7 +621,6 @@ Note that none of these constants are exported by C<Reddit::Client>.
 =item $UA
 
 This is the user agent string, and defaults to C<Reddit::Client/$VERSION>.
-NOTE: This is now deprecated in favor of the user_agent argument to new().
 
 
 =item $DEBUG
@@ -650,13 +634,12 @@ When set to true, outputs a small amount of debugging information.
 
 =over
 
-=item new(user_agent => ..., session_file => ...)
+=item new(session_file => ...)
+
+Begins a new or loads an existing reddit session. If C<session_file> is
+provided, it will be read and parsed as JSON. If session data is found, it
+is restored. Otherwise, a new session is started.
 
-Begins a new or loads an existing reddit session. The C<user_agent> argument
-will be required in a future release. Omitting it will generate a warning.
-If C<session_file> is provided, it will be read and parsed as JSON. If
-session data is found, it is restored. Otherwise, a new session is started.
-Session data does not restore the user_agent string of the original session.
 
 =item is_logged_in
 
@@ -861,10 +844,6 @@ Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+BSD license
 
 =cut
