@@ -1,9 +1,8 @@
 package Reddit::Client::SubReddit;
 
-use strict;
-use warnings;
 use Carp;
 
+require Reddit::Client;
 require Reddit::Client::Thing;
 
 use base   qw/Reddit::Client::Thing/;
@@ -13,17 +12,17 @@ use fields qw/over18 header_img created_utc header_title header_size
 
 sub links {
     my ($self, %param) = @_;
-    return $self->{session}->fetch_links(subreddit => $self->{url}, %param);
+    return $self->{_session}->fetch_links(subreddit => $self->{url}, %param);
 }
 
 sub submit_link {
     my ($self, $title, $url) = @_;
-    $self->{session}->submit_link(title => $title, url => $url, sr => $self->{title}, kind => 'link');
+    $self->{_session}->submit_link(title => $title, url => $url, sr => $self->{title}, kind => 'link');
 }
 
 sub submit_text {
     my ($self, $title, $text) = @_;
-    $self->{session}->submit_text(title => $title, text => $text, sr => $self->{title}, kind => 'text');
+    $self->{_session}->submit_text(title => $title, text => $text, sr => $self->{title}, kind => 'text');
 }
 
 1;
@@ -63,10 +62,6 @@ Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+BSD license
 
 =cut
