@@ -1,7 +1,5 @@
 package Reddit::Client::VotableThing;
 
-use strict;
-use warnings;
 use Carp;
 
 require Reddit::Client::Thing;
@@ -17,32 +15,32 @@ sub set_likes {
 
 sub vote {
     my ($self, $direction) = @_;
-    $self->{session}->vote($self->{name}, $direction);
+    $self->{_session}->vote($self->{name}, $direction);
 }
 
 sub comment {
     my ($self, $comment) = @_;
-    $self->{session}->submit_comment(parent_id => $self->{name}, text => $comment);
+    $self->{_session}->submit_comment(parent_id => $self->{name}, text => $comment);
 }
 
 sub save {
     my $self = shift;
-    $self->{session}->save($self->{name});
+    $self->{_session}->save($self->{name});
 }
 
 sub unsave {
     my $self = shift;
-    $self->{session}->unsave($self->{name});
+    $self->{_session}->unsave($self->{name});
 }
 
 sub hide {
     my $self = shift;
-    $self->{session}->hide($self->{name});
+    $self->{_session}->hide($self->{name});
 }
 
 sub unhide {
     my $self = shift;
-    $self->{session}->unhide($self->{name});
+    $self->{_session}->unhide($self->{name});
 }
 
 1;
@@ -95,10 +93,6 @@ Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+BSD license
 
 =cut
